Wagtail Robots
==============

This is a basic Django application for Wagtail to manage robots.txt files
following the `robots exclusion protocol`_, complementing the Django_
`Sitemap contrib app`_.

This started as a fork of `Django Robots`_ but because of the differences
between the Django Admin and the Wagtail Admin, and other project requirements
git history has not been retained.

For installation and configuration instructions,
`check out the docs`_.

.. _robots exclusion protocol: http://en.wikipedia.org/wiki/Robots_exclusion_standard
.. _Django: http://www.djangoproject.com/
.. _Sitemap contrib app: http://docs.djangoproject.com/en/dev/ref/contrib/sitemaps/
.. _Django Robots: https://github.com/jazzband/django-robots
.. _check out the docs: https://wagtail-robots.readthedocs.io
